@@ -10,12 +10,13 @@ import re
 # Regular expression to match a consecutive run of digits.
 integer_pattern = re.compile('([0-9]+)')
 
-def natsort(l, key=None):
+def natsort(l, key=None, reverse=False):
     """
     Sort the given list in the way that humans expect (using natural order
     sorting).
     """
-    return sorted(l, key=lambda v: natsort_key(key and key(v) or v))
+    return sorted(l, key=lambda v: natsort_key(key and key(v) or v),
+                  reverse=reverse)
 
 def natsort_key(s):
     """
